/* -*- linux-c -*- */


/*
    lm78_smbus.c - Part of a Linux module for reading sensor data.
    Copyright (c) 1998  Philip Edelbrock <phil@netroedge.com>,
    Frodo Looijaard <frodol@dds.nl>, William Morgan <wmorgan@kevol.com>,
    and Alexander Larsson <alla@lysator.liu.se>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
/*
 *  LM78 via SMBus driver for LINUX
 *
 * Copyright (c) 1998 Philip Edelbrock <phil@netroedge.com,
 *  Frodo Looijaard <frodol@dds.nl>, William Morgan <wmorgan@kevol.com>,
 *  and Alexander Larsson <alla@lysator.liu.se>
 * 
 * part of a module which provides a 
 * /proc/sensors file which shows
 * some information about your system.
 * Voltages, temperature and fan speeds
 * are currently reported.
 *
 *
 * please report any bugs/patches to me:
 *  phil@netroedge.com (or the other authors above)
 *
 *
 * Reference:
 *   National Semiconductor
 *   LM78, PDF, April 1997.
 *   http://www.national.com/ds/LM/LM78.pdf
 *
 *   Intel
 *   82371AB PCI-TO-ISA / IDE XCELERATOR (PIIX4), PDF, April 1997.
 *   ftp://ftp.intel.com
 *   
 *   System Management Bus Specification, Rev. 1.0, 1996.
 *   Contributors:
 *   Benchmarq Microelectronics Inc ., Duracell Inc.,
 *   Energizer Power Systems, Intel Corporation, Linear Technology Corporation,
 *   Maxim Integrated Products, Mitsubishi Electric Corporation,
 *   National Semiconductor Corporation, Toshiba Battery Co.,
 *   Varta Batterie AG, All rights reserved.
 *   http://www.sbs-forum.org/
 */

#include <linux/config.h>

/* The next define disables the redefinition of kernel_version. As it is
   already defined and initialized in lm78.c, this would result in twice
   defined symbols. We must include <linux/version.h> by hand now. */
#define __NO_VERSION__

/* Hack to allow the use of CONFIG_MODVERSIONS. In the kernel itself, this
   is arranged from the main Makefile. */
#if CONFIG_MODVERSIONS==1
#define MODVERSIONS
#include <linux/modversions.h>
#endif

#include <linux/module.h>
#include <linux/proc_fs.h>
#include <linux/ioport.h>
#include <asm/io.h>
#include <linux/pci.h>
#include <linux/delay.h>
#include "main.h"
#include "smbus.h"
#include "lm78_smbus.h"

int LM78_SMBus_addr=0x2D;

void LM78_SMBUS_WRITE(int reg, int value ) {
	SMBus_Write(LM78_SMBus_addr,(reg & 0xFF) | ((value & 0xFF) << 8),BYTE_DATA);
}

int LM78_SMBUS_READ(int reg) {
	return (SMBus_Read(LM78_SMBus_addr,(reg & 0xFF),BYTE_DATA) >> 8);
}
